@@ -1,6 +1,30 @@
 """
 更新内容一览
 """
+"""
+2022/10/26
+control_version:0.8.0
+blcoklyFile_version:2.2.11
+blockly_version:2.2.5
+1、将Yuyin类拆成三个类（语音识别，语音合成，聊天机器人）
+2、加入本地化语音识别
+3、更新了语音的编程块,以及整理了所有的编程块
+4、修改util里面的local_yuyin和all_path和checkLibVersion,download
+5、树莓派语音识别测试通过
+"""
+
+
+"""
+2022/10/10
+control_version:0.7.3
+blcoklyFile_version:2.2.10
+blockly_version:2.2.5
+1、加入树莓派版本的本地化语音合成
+2、调整了requirements
+3.GPIO库加入了RGB三色灯的应用
+4、GPIO三色灯优化逻辑与命名
+5、改LCD字体
+"""
 
 
 """
