@@ -14,7 +14,7 @@ import os
 import cv2
 from PIL import Image, ImageDraw, ImageFont, ImageFilter  # 放图片的包
 import logging  # 加载字体
-from util.all_path import system_platform, fonts_path
+from .util.all_path import system_platform, fonts_path
 
 if 'win' in system_platform:
     raise BaseException("请在树莓派上使用本库")
@@ -933,7 +933,7 @@ class Screen:
         """
         下面是字体的选择
         """
-        Font = ImageFont.truetype(os.path.join(fonts_path, "simkai.ttf"), font_size)
+        Font = ImageFont.truetype(os.path.join(fonts_path, "1.ttf"), font_size)
         font_number_max = int(320 / font_size - 1)
         # 字体一行最多的数量
         if len(string) < font_number_max:
@@ -1015,3 +1015,40 @@ class Screen:
                 break
 
         cap.release()
+class RGB():  #是否考虑加入PWM“呼吸灯”技能
+    '''
+    四pin RGB三色灯显示
+    '''
+    def __init__(self, uw_num: int):
+        '''
+        初始化RGB灯的类
+        :param uw_num: RGB灯的接口，整数类型，如1
+        ps：使用的与uw（超声波）同样的串口，所以用同样的字典命名等
+        '''
+        self.__trig_p = UW_IO[uw_num][0]
+        self.__echo_p = UW_IO[uw_num][1]
+        #由于是三色灯，选择变成了两个out的io口
+        GPIO.setup(self.__trig_p, GPIO.OUT)
+        GPIO.setup(self.__echo_p, GPIO.OUT)
+    
+    def LightClose(self):
+        '''
+        关闭灯 对应的 tr ec为 00
+        '''
+        GPIO.output(self.__trig_p, GPIO.LOW)
+        GPIO.output(self.__echo_p, GPIO.LOW)
+    def LightON(self,Color):
+        '''
+        打开某个灯
+        Args：
+            Color：要打开的灯的颜色
+        '''
+        if Color == "Red":  #打开红灯，对应的 tr ec为 01
+            GPIO.output(self.__trig_p, GPIO.LOW)
+            GPIO.output(self.__echo_p, GPIO.HIGH)
+        elif Color == "Yellow":  #打开黄灯，对应的 tr ec为 10
+            GPIO.output(self.__trig_p, GPIO.HIGH)
+            GPIO.output(self.__echo_p, GPIO.LOW)
+        elif Color == "Green":  #打开绿灯，对应的 tr ec为 11
+            GPIO.output(self.__trig_p, GPIO.HIGH)
+            GPIO.output(self.__echo_p, GPIO.HIGH)
